
"""
ARL Infrastructure API

OpenAPI specification for ARL (Agentic RL) Infrastructure custom resources. This SDK provides models for WarmPool, Sandbox, and Task Kubernetes custom resources.

The version of the OpenAPI document: v1alpha1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self

from .models.warm_pool_spec_template_spec_affinity_pod_affinity_preferred_during_scheduling_ignored_during_execution_inner_pod_affinity_term_label_selector import (
    WarmPoolSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionInnerPodAffinityTermLabelSelector,
)
from .models.warm_pool_spec_template_spec_volumes_inner_ephemeral_volume_claim_template_spec_data_source import (
    WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecDataSource,
)
from .models.warm_pool_spec_template_spec_volumes_inner_ephemeral_volume_claim_template_spec_data_source_ref import (
    WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecDataSourceRef,
)
from .models.warm_pool_spec_template_spec_volumes_inner_ephemeral_volume_claim_template_spec_resources import (
    WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources,
)


class WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpec(BaseModel):
    """
    WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpec
    """

    access_modes: list[StrictStr] | None = Field(default=None, alias="accessModes")
    data_source: WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecDataSource | None = Field(default=None, alias="dataSource")
    data_source_ref: WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecDataSourceRef | None = Field(default=None, alias="dataSourceRef")
    resources: WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources | None = None
    selector: WarmPoolSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionInnerPodAffinityTermLabelSelector | None = None
    storage_class_name: StrictStr | None = Field(default=None, alias="storageClassName")
    volume_attributes_class_name: StrictStr | None = Field(
        default=None, alias="volumeAttributesClassName"
    )
    volume_mode: StrictStr | None = Field(default=None, alias="volumeMode")
    volume_name: StrictStr | None = Field(default=None, alias="volumeName")
    __properties: ClassVar[list[str]] = [
        "accessModes",
        "dataSource",
        "dataSourceRef",
        "resources",
        "selector",
        "storageClassName",
        "volumeAttributesClassName",
        "volumeMode",
        "volumeName",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self | None:
        """Create an instance of WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpec from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of data_source
        if self.data_source:
            _dict["dataSource"] = self.data_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of data_source_ref
        if self.data_source_ref:
            _dict["dataSourceRef"] = self.data_source_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of resources
        if self.resources:
            _dict["resources"] = self.resources.to_dict()
        # override the default output from pydantic by calling `to_dict()` of selector
        if self.selector:
            _dict["selector"] = self.selector.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict[str, Any] | None) -> Self | None:
        """Create an instance of WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpec from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "accessModes": obj.get("accessModes"),
                "dataSource": WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecDataSource.from_dict(
                    obj["dataSource"]
                )
                if obj.get("dataSource") is not None
                else None,
                "dataSourceRef": WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecDataSourceRef.from_dict(
                    obj["dataSourceRef"]
                )
                if obj.get("dataSourceRef") is not None
                else None,
                "resources": WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources.from_dict(
                    obj["resources"]
                )
                if obj.get("resources") is not None
                else None,
                "selector": WarmPoolSpecTemplateSpecAffinityPodAffinityPreferredDuringSchedulingIgnoredDuringExecutionInnerPodAffinityTermLabelSelector.from_dict(
                    obj["selector"]
                )
                if obj.get("selector") is not None
                else None,
                "storageClassName": obj.get("storageClassName"),
                "volumeAttributesClassName": obj.get("volumeAttributesClassName"),
                "volumeMode": obj.get("volumeMode"),
                "volumeName": obj.get("volumeName"),
            }
        )
        return _obj
