
"""
ARL Infrastructure API

OpenAPI specification for ARL (Agentic RL) Infrastructure custom resources. This SDK provides models for WarmPool, Sandbox, and Task Kubernetes custom resources.

The version of the OpenAPI document: v1alpha1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar

from pydantic import BaseModel, ConfigDict
from typing_extensions import Self

from .models.sandbox_spec_resources_limits_value import SandboxSpecResourcesLimitsValue


class WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources(BaseModel):
    """
    WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources
    """

    limits: dict[str, SandboxSpecResourcesLimitsValue] | None = None
    requests: dict[str, SandboxSpecResourcesLimitsValue] | None = None
    __properties: ClassVar[list[str]] = ["limits", "requests"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self | None:
        """Create an instance of WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in limits (dict)
        _field_dict = {}
        if self.limits:
            for _key_limits in self.limits:
                if self.limits[_key_limits]:
                    _field_dict[_key_limits] = self.limits[_key_limits].to_dict()
            _dict["limits"] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in requests (dict)
        _field_dict = {}
        if self.requests:
            for _key_requests in self.requests:
                if self.requests[_key_requests]:
                    _field_dict[_key_requests] = self.requests[_key_requests].to_dict()
            _dict["requests"] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict[str, Any] | None) -> Self | None:
        """Create an instance of WarmPoolSpecTemplateSpecVolumesInnerEphemeralVolumeClaimTemplateSpecResources from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "limits": dict(
                    (_k, SandboxSpecResourcesLimitsValue.from_dict(_v))
                    for _k, _v in obj["limits"].items()
                )
                if obj.get("limits") is not None
                else None,
                "requests": dict(
                    (_k, SandboxSpecResourcesLimitsValue.from_dict(_v))
                    for _k, _v in obj["requests"].items()
                )
                if obj.get("requests") is not None
                else None,
            }
        )
        return _obj
