
"""
ARL Infrastructure API

OpenAPI specification for ARL (Agentic RL) Infrastructure custom resources. This SDK provides models for WarmPool, Sandbox, and Task Kubernetes custom resources.

The version of the OpenAPI document: v1alpha1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re
from datetime import datetime
from typing import Annotated, Any, ClassVar

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing_extensions import Self


class Condition(BaseModel):
    """
    Condition
    """

    last_transition_time: datetime = Field(alias="lastTransitionTime")
    message: Annotated[str, Field(strict=True, max_length=32768)]
    observed_generation: Annotated[int, Field(strict=True, ge=0)] | None = Field(
        default=None, alias="observedGeneration"
    )
    reason: Annotated[str, Field(min_length=1, strict=True, max_length=1024)]
    status: StrictStr
    type: Annotated[str, Field(strict=True, max_length=316)]
    __properties: ClassVar[list[str]] = [
        "lastTransitionTime",
        "message",
        "observedGeneration",
        "reason",
        "status",
        "type",
    ]

    @field_validator("reason")
    def reason_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$", value):
            raise ValueError(
                r"must validate the regular expression /^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$/"
            )
        return value

    @field_validator("status")
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(["True", "False", "Unknown"]):
            raise ValueError("must be one of enum values ('True', 'False', 'Unknown')")
        return value

    @field_validator("type")
    def type_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(
            r"^([a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\/)?(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])$",
            value,
        ):
            raise ValueError(
                r"must validate the regular expression /^([a-z0-9]([-a-z0-9]*[a-z0-9])?(\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\/)?(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])$/"
            )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self | None:
        """Create an instance of Condition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: dict[str, Any] | None) -> Self | None:
        """Create an instance of Condition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "lastTransitionTime": obj.get("lastTransitionTime"),
                "message": obj.get("message"),
                "observedGeneration": obj.get("observedGeneration"),
                "reason": obj.get("reason"),
                "status": obj.get("status"),
                "type": obj.get("type"),
            }
        )
        return _obj
